==> mergerfs_2.31.0.orig.tar.gz: mergerfs-2.31.0/src/fs_fsetxattr.hpp <==
/*
  ISC License

  Copyright (c) 2020, Antonio SJ Musumeci <trapexit@spawn.link>

  Permission to use, copy, modify, and/or distribute this software for any
  purpose with or without fee is hereby granted, provided that the above
  copyright notice and this permission notice appear in all copies.

  THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
  WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
  MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
  ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
  WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
  ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
  OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
*/

#pragma once

#include "errno.hpp"
#include "xattr.hpp"

#include <string>

#include <sys/types.h>

namespace fs
{
  static
  inline
  int
  fsetxattr(const int     fd_,
            const char   *name_,
            const void   *value_,
            const size_t  size_,
            const int     flags_)
  {
#ifdef USE_XATTR
    return ::fsetxattr(fd_,name_,value_,size_,flags_);
#else
    return (errno=ENOTSUP,-1);
#endif
  }

  static
  inline
  int
  fsetxattr(const int          fd_,
            const std::string &name_,
            const void        *value_,
            const size_t       size_,
            const int          flags_)
  {
    return fs::fsetxattr(fd_,
                         name_.c_str(),
                         value_,
                         size_,
                         flags_);
  }
}

==> mergerfs-2.41.1.tar.gz: mergerfs-2.41.1/src/fs_fsetxattr.hpp <==
/*
  ISC License

  Copyright (c) 2020, Antonio SJ Musumeci <trapexit@spawn.link>

  Permission to use, copy, modify, and/or distribute this software for any
  purpose with or without fee is hereby granted, provided that the above
  copyright notice and this permission notice appear in all copies.

  THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
  WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
  MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
  ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
  WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
  ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
  OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
*/

#pragma once

#include "to_neg_errno.hpp"
#include "xattr.hpp"

#include <string>

#include <sys/types.h>


namespace fs
{
  static
  inline
  int
  fsetxattr(const int     fd_,
            const char   *name_,
            const void   *value_,
            const size_t  size_,
            const int     flags_)
  {
#ifdef USE_XATTR
    int rv;

    rv = ::fsetxattr(fd_,name_,value_,size_,flags_);

    return ::to_neg_errno(rv);
#else
    return -ENOTSUP;
#endif
  }

  static
  inline
  int
  fsetxattr(const int          fd_,
            const std::string &name_,
            const void        *value_,
            const size_t       size_,
            const int          flags_)
  {
    return fs::fsetxattr(fd_,
                         name_.c_str(),
                         value_,
                         size_,
                         flags_);
  }
}
